@@ -41,6 +41,14 @@ register_mlr3 = function() {
   x$add("clust.cmeans", LearnerClustCMeans)
   x$add("clust.dbscan", LearnerClustDBSCAN)
   x$add("clust.xmeans", LearnerClustXMeans)
+  x$add("clust.cobweb", LearnerClustCobweb)
+  x$add("clust.em", LearnerClustEM)
+  x$add("clust.ff", LearnerClustFarthestFirst)
+  x$add("clust.SimpleKMeans", LearnerClustSimpleKMeans)
+  x$add("clust.MBatchKMeans", LearnerClustMiniBatchKMeans)
+  x$add("clust.kkmeans", LearnerClustKKMeans)
+  x$add("clust.ap", LearnerClustAP)
+  x$add("clust.meanshift", LearnerClustMeanShift)
 
   x = utils::getFromNamespace("mlr_measures", ns = "mlr3")
   x$add("clust.db", MeasureClustInternal, name = "db")
